"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.suite_list_response_all_of_result import SuiteListResponseAllOfResult
globals()['SuiteListResponseAllOfResult'] = SuiteListResponseAllOfResult
from qaseio.model.suite_list_response_all_of import SuiteListResponseAllOf


class TestSuiteListResponseAllOf(unittest.TestCase):
    """SuiteListResponseAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSuiteListResponseAllOf(self):
        """Test SuiteListResponseAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SuiteListResponseAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
