"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.filters import Filters


class TestFilters(unittest.TestCase):
    """Filters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testFilters(self):
        """Test Filters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Filters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
