"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.plan_list_response_all_of import PlanListResponseAllOf
from qaseio.model.plan_list_response_all_of_result import PlanListResponseAllOfResult
from qaseio.model.response import Response
globals()['PlanListResponseAllOf'] = PlanListResponseAllOf
globals()['PlanListResponseAllOfResult'] = PlanListResponseAllOfResult
globals()['Response'] = Response
from qaseio.model.plan_list_response import PlanListResponse


class TestPlanListResponse(unittest.TestCase):
    """PlanListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPlanListResponse(self):
        """Test PlanListResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PlanListResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
