"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import qaseio
from qaseio.api.projects_api import ProjectsApi  # noqa: E501


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self):
        self.api = ProjectsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_project(self):
        """Test case for create_project

        Create new project.  # noqa: E501
        """
        pass

    def test_delete_project(self):
        """Test case for delete_project

        Delete Project by code.  # noqa: E501
        """
        pass

    def test_get_project(self):
        """Test case for get_project

        Get Project by code.  # noqa: E501
        """
        pass

    def test_get_projects(self):
        """Test case for get_projects

        Get All Projects.  # noqa: E501
        """
        pass

    def test_grant_access_to_project(self):
        """Test case for grant_access_to_project

        Grant access to project by code.  # noqa: E501
        """
        pass

    def test_revoke_access_to_project(self):
        """Test case for revoke_access_to_project

        Revoke access to project by code.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
