"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import qaseio
from qaseio.api.suites_api import SuitesApi  # noqa: E501


class TestSuitesApi(unittest.TestCase):
    """SuitesApi unit test stubs"""

    def setUp(self):
        self.api = SuitesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_suite(self):
        """Test case for create_suite

        Create a new test suite.  # noqa: E501
        """
        pass

    def test_delete_suite(self):
        """Test case for delete_suite

        Delete test suite.  # noqa: E501
        """
        pass

    def test_get_suite(self):
        """Test case for get_suite

        Get a specific test suite.  # noqa: E501
        """
        pass

    def test_get_suites(self):
        """Test case for get_suites

        Get all test suites.  # noqa: E501
        """
        pass

    def test_update_suite(self):
        """Test case for update_suite

        Update test suite.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
