"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.custom_fields_response_all_of import CustomFieldsResponseAllOf
from qaseio.model.custom_fields_response_all_of_result import CustomFieldsResponseAllOfResult
from qaseio.model.response import Response
globals()['CustomFieldsResponseAllOf'] = CustomFieldsResponseAllOf
globals()['CustomFieldsResponseAllOfResult'] = CustomFieldsResponseAllOfResult
globals()['Response'] = Response
from qaseio.model.custom_fields_response import CustomFieldsResponse


class TestCustomFieldsResponse(unittest.TestCase):
    """CustomFieldsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCustomFieldsResponse(self):
        """Test CustomFieldsResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CustomFieldsResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
