"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.response import Response
from qaseio.model.result import Result
from qaseio.model.result_response_all_of import ResultResponseAllOf
globals()['Response'] = Response
globals()['Result'] = Result
globals()['ResultResponseAllOf'] = ResultResponseAllOf
from qaseio.model.result_response import ResultResponse


class TestResultResponse(unittest.TestCase):
    """ResultResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testResultResponse(self):
        """Test ResultResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ResultResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
