"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import qaseio
from qaseio.api.environments_api import EnvironmentsApi  # noqa: E501


class TestEnvironmentsApi(unittest.TestCase):
    """EnvironmentsApi unit test stubs"""

    def setUp(self):
        self.api = EnvironmentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_environment(self):
        """Test case for create_environment

        Create a new environment.  # noqa: E501
        """
        pass

    def test_delete_environment(self):
        """Test case for delete_environment

        Delete environment.  # noqa: E501
        """
        pass

    def test_get_environment(self):
        """Test case for get_environment

        Get a specific environment.  # noqa: E501
        """
        pass

    def test_get_environments(self):
        """Test case for get_environments

        Get all environments.  # noqa: E501
        """
        pass

    def test_update_environment(self):
        """Test case for update_environment

        Update environment.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
