"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.id_response_all_of import IdResponseAllOf
from qaseio.model.id_response_all_of_result import IdResponseAllOfResult
from qaseio.model.response import Response
globals()['IdResponseAllOf'] = IdResponseAllOf
globals()['IdResponseAllOfResult'] = IdResponseAllOfResult
globals()['Response'] = Response
from qaseio.model.id_response import IdResponse


class TestIdResponse(unittest.TestCase):
    """IdResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testIdResponse(self):
        """Test IdResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = IdResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
