"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.custom_field import CustomField
globals()['CustomField'] = CustomField
from qaseio.model.custom_fields_response_all_of_result import CustomFieldsResponseAllOfResult


class TestCustomFieldsResponseAllOfResult(unittest.TestCase):
    """CustomFieldsResponseAllOfResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCustomFieldsResponseAllOfResult(self):
        """Test CustomFieldsResponseAllOfResult"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CustomFieldsResponseAllOfResult()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
